unofficial mirror of guix-devel@gnu.org 
 help / color / mirror / code / Atom feed
blob a2145274cb9c9410a662891eacdf07839604d91b 1640 bytes (raw)
name: packages/patches/ganeti-procps-compat.patch 	 # note: path name is non-authoritative(*)

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
 
Fix compatibility with procps 4.

Negative UIDs are no longer allowed.  Use a very high one instead.

Taken from upstream:

  https://github.com/ganeti/ganeti/commit/9cd67e6a81c66ed326d68ea8c3241d14eea6550b

diff --git a/test/py/ganeti.uidpool_unittest.py b/test/py/ganeti.uidpool_unittest.py
index b2f5bc5cf2..2d9227cbf5 100755
--- a/test/py/ganeti.uidpool_unittest.py
+++ b/test/py/ganeti.uidpool_unittest.py
@@ -106,23 +106,24 @@ def testRequestUnusedUid(self):
 
     # Check with a single, known unused user-id
     #
-    # We use "-1" here, which is not a valid user-id, so it's
-    # guaranteed that it's unused.
-    uid = uidpool.RequestUnusedUid(set([-1]))
-    self.assertEqualValues(uid.GetUid(), -1)
+    # We use 2^30+42 here, which is a valid UID, but unlikely to be used on
+    # most systems (even as a subuid).
+    free_uid = 2**30 + 42
+    uid = uidpool.RequestUnusedUid(set([free_uid]))
+    self.assertEqualValues(uid.GetUid(), free_uid)
 
     # Check uid-pool exhaustion
     #
     # uid "-1" is locked now, so RequestUnusedUid is expected to fail
     self.assertRaises(errors.LockError,
                       uidpool.RequestUnusedUid,
-                      set([-1]))
+                      set([free_uid]))
 
     # Check unlocking
     uid.Unlock()
     # After unlocking, "-1" should be available again
-    uid = uidpool.RequestUnusedUid(set([-1]))
-    self.assertEqualValues(uid.GetUid(), -1)
+    uid = uidpool.RequestUnusedUid(set([free_uid]))
+    self.assertEqualValues(uid.GetUid(), free_uid)
 
 
 if __name__ == "__main__":
@@ -106,23 +106,24 @@ def testRequestUnusedUid(self):
     # Check uid-pool exhaustion
     #
-    # uid "-1" is locked now, so RequestUnusedUid is expected to fail
+    # free_uid is locked now, so RequestUnusedUid is expected to fail
     self.assertRaises(errors.LockError,
                       uidpool.RequestUnusedUid,

debug log:

solving a2145274cb9c9410a662891eacdf07839604d91b ...
found a2145274cb9c9410a662891eacdf07839604d91b in https://git.savannah.gnu.org/cgit/guix.git

(*) Git path names are given by the tree(s) the blob belongs to.
    Blobs themselves have no identifier aside from the hash of its contents.^

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/guix.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).